@@ -44,12 +44,12 @@ public:
 	SSLConnect( QObject *parent = 0 );
 	~SSLConnect();
 
-	bool isLoaded();
 	QByteArray getUrl( RequestType type, const QString &value = "" );
 
 	QString pin() const;
 	void setCard( const QString &card );
 	void setPin( const QString &pin );
+	void setPKCS11( const QString &pkcs11 );
 	void setReader( int reader );
 
 private:
