@@ -22,7 +22,7 @@
 
 #include "CertUpdate.h"
 
-#include <cardlib/helperMacro.h>
+#include <smartcard++/helperMacro.h>
 
 #include <QApplication>
 #include <QDateTime>
@@ -76,7 +76,7 @@ bool CertUpdate::checkConnection() const
 bool CertUpdate::checkUpdateAllowed()
 {
 	QByteArray result = QByteArray::fromHex( runStep( step ) );
-	if ( result.isEmpty() || result.size() != 22 )
+	if ( result.isEmpty() || result.size() != 22 || result.size() < 22 )
 		throwError( tr("Check internet connection") );
 	if ( result.at(4) == 0x06 )
 		generateKeys = true;
@@ -150,7 +150,7 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 				qDebug() << "runtime8: " << e.what();
 				throw std::runtime_error( "step8 runtime error" );
 			}
-			if ( result.isEmpty() || result.size() != 33 )
+			if ( result.isEmpty() || result.size() != 33 || result.size() < 22 )
 				throw std::runtime_error( "step8" );
 
 			if( result.at(11) == 0x12 )
@@ -320,10 +320,10 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 				qDebug() << "runtime21: " << e.what();
 				throw std::runtime_error( "step21 runtime error" );
 			}
-			if ( result.isEmpty() || result.size() != 147 )
+			if ( result.isEmpty() || result.size() != 147 || result.size() < 134 )
 				throw std::runtime_error( "step21a" );
 		
-			if ( result.at( 132 ) == char(0x34) && result.at( 133 ) >= char(0x80) )
+			if ((unsigned char)result.at( 132 ) == 0x34 && (unsigned char)result.at( 133 ) >= 0x80 )
 			{
 				runStep( 3 );
 				runStep( 4 );
@@ -398,14 +398,14 @@ QByteArray CertUpdate::runStep( int s, QByteArray result )
 				qDebug() << "runtime25: " << e.what();
 				throw std::runtime_error( "step25 runtime error" );
 			}
-			if ( result.isEmpty() || result.size() != 147 )
+			if ( result.isEmpty() || result.size() != 147 || result.size() < 134 )
 				throw std::runtime_error( "step25a" );
 
 			QByteArray tmpResult = QByteArray::fromHex( queryServer( s, result ).remove( 0, 16 ) );
 			if ( tmpResult.isEmpty() || tmpResult.size() != 114 )
 				throw std::runtime_error( "step25b" );
 
-			if ( result.at( 133 ) >= char(0x80) )
+			if ( (unsigned char)result.at( 133 ) >= 0x80 )
 			{
 				runStep( 3 );
 				runStep( 4 );
