@@ -33,14 +33,14 @@ function checkAccessKeys(e)
 
 function checkNumeric(e)
 {
-	if ( e.keyCode == 13 || e.keyCode == 8 || e.keyCode == 0 || String.fromCharCode(e.keyCode).match(/[\d]/) )
+	if ( e.keyCode == 13 || e.keyCode == 9 || e.keyCode == 8 || e.keyCode == 0 || String.fromCharCode(e.keyCode).match(/[\d]/) )
 		return true;
 	return false;
 }
 
 function handlekey(nextItem)
 {
-	if ( window.event.keyCode != 13 )
+	if ( window.event.keyCode != 13 && window.event.keyCode != 9 )
 		return;
 
 	var el = document.getElementById(nextItem)
@@ -53,6 +53,12 @@ function handlekey(nextItem)
 		el.click();
 }
 
+function checkEnter( e, obj )
+{
+	if ( e.keyCode == 13 && ( typeof obj.click != "undefined" ) && obj.click )
+		obj.click();
+}
+
 function cardInserted(i)
 {
 	//alert("Kaart sisestati lugejasse " + cardManager.getReaderName(i))
@@ -80,17 +86,18 @@ function cardInserted(i)
 					}
 					retry--;
 				}
-				extender.closeLoading();
+				if ( activeCardId != '' || !cardManager.anyCardsInReader() )
+					extender.closeLoading();
 			}
 		} else
 			inReader = true;
 	} catch ( err ) {}
 
-	if ( activeCardId == "" )
+	if ( activeCardId == "" && !cardManager.anyCardsInReader() )
 		document.getElementById('cardInfoNoCard').style.display='block';
 		
 	document.getElementById( 'forUpdate' ).innerHTML += ".";
-	if ( !inReader )
+	if ( !inReader && activeCardId != '' )
 		readCardData();
 }
 
@@ -109,9 +116,17 @@ function cardRemoved(i)
 			emailsLoaded = false;
 			activeCardId = "";
 			disableFields();
-			cardManager.findCard();
-			if ( esteidData.canReadCard() )
-				activeCardId = esteidData.getDocumentId();
+			var retry = 3;
+			while( retry > 0 )
+			{
+				cardManager.findCard();
+				if ( esteidData.canReadCard() )
+				{
+					activeCardId = esteidData.getDocumentId();
+					break;
+				}
+				retry--;
+			}
 		} else
 			inReader = true;
 	} catch( err ) {}
@@ -136,7 +151,7 @@ function selectReader()
 		activeCardId = esteidData.getDocumentId();
 
 	extender.closeLoading();
-	document.getElementById( 'forUpdate' ).innerHTML += " ";
+	document.getElementById( 'forUpdate' ).innerHTML += ".";
 	readCardData();
 }
 
@@ -396,9 +411,11 @@ function setActive( content, el )
 			{
 				document.getElementById('buttonChangePUK2').style.display = 'none';
 				document.getElementById('labelPUKBlocked').style.display = 'block';
+				document.getElementById('chanePIN4PUK').style.display = 'none';
 			} else {
 				document.getElementById('buttonChangePUK2').style.display = 'block';
 				document.getElementById('labelPUKBlocked').style.display = 'none';
+				document.getElementById('chanePIN4PUK').style.display = 'block';
 			}
 			break;
 	}
@@ -582,6 +599,7 @@ function enableFields()
 
 	document.getElementById('buttonChangePUK2').style.display = 'block';
 	document.getElementById('labelPUKBlocked').style.display = 'none';
+	document.getElementById('chanePIN4PUK').style.display = 'block';
 }
 
 function checkMobile()
